#ifndef SVN_VERSION_H
#define SVN_VERSION_H

#define SVN_VERSION "2bae9d7e425c22cb3451fa8f5f15117027b3d27e [/startdir/boinc] (archlinux:/build/boinc/src/boinc [makepkg]) [Server-Release: server_release/1.x/1.x.0-3405-g2bae9d7e425c22cb3451fa8f5f15117027b3d27e]"
#define GIT_REVISION 0x2bae9d7e
#define GIT_DATE 1776373059
#define REPOSITORY__STARTDIR_BOINC 1

#endif
